require 'spec_helper'

describe "as an anonymous client" do
  let!(:client) { create_anonymous_client }

  it "should create a user" do
    username = SecureRandom.hex(6)
    password = SecureRandom.hex(6)
    email    = Faker::Internet.email

    client.users.create(email: email, username: username, password: password)

    if Deis::Client.mocking?
      user = client.data[:users].values.first

      expect(user["email"]).to    eq(email)
      expect(user["username"]).to eq(username)
      expect(user["password"]).to eq(password)
    end
  end

  describe "#register_user" do
    it "should create a new user" do
      response = client.register_user(
        "username" => (username = SecureRandom.hex(6)),
        "password" => (password = SecureRandom.hex(6)),
        "email"    => Faker::Internet.email,
      )

      expect(response.status).to eq(201)

      user = response.body

      expect(user["username"]).to eq(username)
      expect(user["password"]).to eq(password)

      if Deis::Client.mocking?
        expect(user["is_superuser"]).to eq(true)
        expect(user["is_staff"]).to     eq(true)
      end

      response = client.register_user(
        "username" => SecureRandom.hex(6),
        "password" => SecureRandom.hex(6),
      )

      another_user = response.body

      expect(another_user["is_superuser"]).to eq(false)
      expect(another_user["is_staff"]).to     eq(false)
    end
  end
end
